@@ -35,4 +35,17 @@ def do_dput(self, subcmd, opts, *args):
     if hasattr(self, "osc_plugin_dput"):
         osc_plugin_dput = self.osc_plugin_dput  # noqa: F811
 
+    # osc 1.x removes get_cmd_help, inject a replacement
+    if not hasattr(self, "get_cmd_help"):
+        import argparse
+
+        def format_help(subcmd, opts=None, *args):
+            for action in self.argparser._actions:
+                if not isinstance(action, argparse._SubParsersAction):
+                    continue
+                for choice, subparser in action.choices.items():
+                    if choice == subcmd:
+                        return subparser.format_help()
+        self.get_cmd_help = format_help
+
     osc_plugin_dput.do_dput(self, subcmd, opts, *args)
