@@ -191,7 +191,9 @@ def do_dput(self, subcmd, opts, *args):
         # Remove old files, but only those that are part of the Debian package
         superseded = set()
         retained = set()
-        downloaded = set()
+
+        # osc <1.6.1 doesn't automatically escape path members.
+        should_escape_filename = osc.core.makeurl('', ['+']) == '/+'
 
         for f in remote_file_list.keys():
             if f.endswith('.dsc'):
@@ -199,13 +201,16 @@ def do_dput(self, subcmd, opts, *args):
                                      ['source',
                                       proj_name,
                                       package_name,
-                                      pathname2url(f)],
+                                      pathname2url(f)
+                                        if should_escape_filename
+                                        else f],
                                      query={})
 
                 remote_dsc = Dsc(osc.core.streamfile(u, bufsize='line'))
 
                 for entry in remote_dsc.get('Files'):
-                    superseded.add(entry['name'])
+                    if entry['name'] in remote_file_list:
+                        superseded.add(entry['name'])
 
                 superseded.add(f)
             elif f.endswith('.changes'):
@@ -232,7 +237,7 @@ def do_dput(self, subcmd, opts, *args):
         os.symlink(dsc_file, f)
         package.addfile(f)
 
-        if opts.maintained_in_git and 'MAINTAINED_IN_GIT.txt' not in retained:
+        if opts.maintained_in_git:
             open('MAINTAINED_IN_GIT.txt', 'w+').close()
             package.addfile('MAINTAINED_IN_GIT.txt')
 
@@ -241,9 +246,6 @@ def do_dput(self, subcmd, opts, *args):
         # the source package
         msg = f
 
-        for f in downloaded:
-            package.addfile(f)
-
         if changes is not None:
             f = dsc_or_changes_file.name
             os.symlink(dsc_or_changes_file, f)
